/*
 * Copyright (c) 2004 - 2007, Tranql project contributors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package org.tranql.connector.postgresql;

import java.sql.SQLException;
import org.postgresql.xa.PGXADataSource;
import org.tranql.connector.NoExceptionsAreFatalSorter;
import org.tranql.connector.jdbc.AbstractXADataSourceMCF;


/**
 * ManagedConnectionFactory that wraps a PostgreSQL XADataSource
 *
 * @version $Revision: 665 $ $Date: 2009-10-05 12:47:47 -0700 (Mon, 05 Oct 2009) $
 */


public class PGXAMCF extends AbstractXADataSourceMCF<PGXADataSource> {


    private String password = "";

    /**
     * Default constructor for a PostgreSQL Embedded XA DataSource.
     */
    public PGXAMCF() {
        super(new PGXADataSource(), new NoExceptionsAreFatalSorter());
    }

    /* (non-Javadoc)
    * @see org.tranql.connector.UserPasswordManagedConnectionFactory#getUserName()
    */
    public String getUserName() {
        return xaDataSource.getUser();
    }

    /**
     * Set the user name used establish the connection. This value is used if no
     * connection information is supplied by the application when attempting to
     * create a connection.
     *
     * @param user the new user name
     */
    public void setUserName(String user) {
        xaDataSource.setUser(user);
    }

    /**
     * Return the password credential used to establish the connection.
     *
     * @return the password credential used to establish the connection
     */

    public String getPassword() {
        return password;
    }

    /**
     * Set the user password credential establish the connection. This value is
     * used if no connection information is supplied by the application when
     * attempting to create a connection.
     *
     * @param pwd the pwd
     */
    public void setPassword(String pwd) {
        this.password = pwd;
        xaDataSource.setPassword(pwd);
    }

    /**
     * Returns the name of the database. This name is used as the database
     * portion of the connection URL.
     *
     * @return the database name
     */
    public String getDatabaseName() {
        return xaDataSource.getDatabaseName();
    }

    /**
     * Specifies the name of the database to connect to. This name is used as
     * the database portion of the connection URL.
     *
     * @param name the database name
     */
    public void setDatabaseName(String name) {
        xaDataSource.setDatabaseName(name);
    }

    /**
     * Returns the port number used to connect to the remote database system.
     *
     * @return the port number
     */
    public Integer getPortNumber() {
        return xaDataSource.getPortNumber();
    }


    /**
     * Specifies the port number to connect to for a remote database server.
     *
     * @param portNumber the port number
     */
    public void setPortNumber(Integer portNumber) {
        xaDataSource.setPortNumber(portNumber);
    }

    /**
     * Gets the prepare threshold.
     *
     * @return the prepare threshold
     * @see org.postgresql.ds.common.BaseDataSource#getPrepareThreshold()
     */
    public Integer getPrepareThreshold() {
        return xaDataSource.getPrepareThreshold();
    }

    /**
     * Sets the prepare threshold.
     *
     * @param prepareThreshold the arg0
     * @see org.postgresql.ds.common.BaseDataSource#setPrepareThreshold(int)
     */
    public void setPrepareThreshold(Integer prepareThreshold) {
        xaDataSource.setPrepareThreshold(prepareThreshold);
    }

    /**
     * Returns the name of the remote server providing RDBMS connectivity.
     *
     * @return the host name of the remote database server.
     */

    public String getServerName() {
        return xaDataSource.getServerName();
    }


    /**
     * Used to specify the name of the server that provides database services.
     *
     * @param serverName the server name
     */
    public void setServerName(String serverName) {
        xaDataSource.setServerName(serverName);
    }

    /**
     * @see org.postgresql.ds.common.BaseDataSource#setLoginTimeout(java.lang.String)
     */
    public void setLoginTimeout(int s) throws SQLException {
        xaDataSource.setLoginTimeout(s);
    }

    /**
     * @param enabled
     * @see org.postgresql.ds.common.BaseDataSource#setSsl(boolean)
     */
    public void setSsl(boolean enabled) {
        xaDataSource.setSsl(enabled);
    }

    /**
     * @return
     * @see org.postgresql.ds.common.BaseDataSource#getSsl()
     */
    public boolean getSsl() {
        return xaDataSource.getSsl();
    }

    /**
     * @param classname
     * @see org.postgresql.ds.common.BaseDataSource#setSslfactory(java.lang.String)
     */
    public void setSslfactory(String classname) {
        xaDataSource.setSslfactory(classname);
    }

    /**
     * @return
     * @see org.postgresql.ds.common.BaseDataSource#getSslFactory()
     */
    public String getSslfactory() {
        return xaDataSource.getSslfactory();
    }

}
